@@ -15,34 +15,34 @@ library refer to `its documentation
 First we'll load in the data using GeoPandas.
 """
 import geopandas
+import geoplot
 
-path = geopandas.datasets.get_path('naturalearth_lowres')
-df = geopandas.read_file(path)
-# Add a column we'll use later
-df['gdp_pp'] = df['gdp_md_est'] / df['pop_est']
-
-boroughs = geopandas.read_file(geopandas.datasets.get_path('nybb')).to_crs(epsg='4326')
-injurious_collisions = geopandas.read_file(
-    "https://github.com/ResidentMario/geoplot-data/raw/master/nyc-injurious-collisions.geojson")
-
+world = geopandas.read_file(
+    geopandas.datasets.get_path('naturalearth_lowres')
+)
+boroughs = geopandas.read_file(
+    geoplot.datasets.get_path('nyc_boroughs')
+)
+collisions = geopandas.read_file(
+    geoplot.datasets.get_path('nyc_injurious_collisions')
+)
 
 ###############################################################################
 # Plotting with Geoplot
 # =====================
 #
 # We start out by replicating the basic GeoPandas world plot using Geoplot.
-import geoplot
-
-geoplot.polyplot(df, figsize=(8, 4))
+geoplot.polyplot(world, figsize=(8, 4))
 
 ###############################################################################
 # Geoplot can re-project data into any of the map projections provided by
 # CartoPy (see the list
 # `here <http://scitools.org.uk/cartopy/docs/latest/crs/projections.html>`_).
 
-import geoplot.crs as gcrs
-ax = geoplot.polyplot(df, projection=gcrs.Orthographic(), figsize=(8, 4))
-ax.set_global()
+# use the Orthographic map projection (e.g. a world globe)
+ax = geoplot.polyplot(
+    world, projection=geoplot.crs.Orthographic(), figsize=(8, 4)
+)
 ax.outline_patch.set_visible(True)
 
 ###############################################################################
@@ -50,39 +50,49 @@ ax.outline_patch.set_visible(True)
 # you want to use color as a visual variable, specify a ``choropleth``. Here
 # we sort GDP per person by country into five buckets by color.
 
-geoplot.choropleth(df, hue='gdp_pp', cmap='Greens', figsize=(8, 4))
+geoplot.choropleth(
+    world, hue=world['gdp_md_est'] / world['pop_est'],
+    cmap='Greens', figsize=(8, 4)
+)
 
 ###############################################################################
-# If you want to use size as a visual variable, you want a ``cartogram``. Here
-# are population estimates for countries in Africa.
+# If you want to use size as a visual variable, use a ``cartogram``. Here are
+# population estimates for countries in Africa.
 
-geoplot.cartogram(df[df['continent'] == 'Africa'],
-                  scale='pop_est', limits=(0.2, 1), figsize=(7, 8))
+africa = world.query('continent == "Africa"')
+ax = geoplot.cartogram(
+    africa, scale='pop_est', limits=(0.2, 1),
+    edgecolor='None', figsize=(7, 8)
+)
+geoplot.polyplot(africa, edgecolor='gray', ax=ax)
 
 ###############################################################################
 # If we have data in the shape of points in space, we may generate a
-# three-dimensional heatmap on it using ``kdeplot``. This example also
-# demonstrates how easy it is to stack plots on top of one another.
+# three-dimensional heatmap on it using ``kdeplot``.
 
-ax = geoplot.kdeplot(injurious_collisions.sample(1000),
-                     shade=True, shade_lowest=False,
-                     clip=boroughs.geometry)
-geoplot.polyplot(boroughs, ax=ax)
+ax = geoplot.kdeplot(
+    collisions, clip=boroughs.geometry,
+    shade=True, cmap='Reds',
+    projection=geoplot.crs.AlbersEqualArea())
+geoplot.polyplot(boroughs, ax=ax, zorder=1)
 
 ###############################################################################
 # Alternatively, we may partition the space into neighborhoods automatically,
-# using Voronoi tessellation.
+# using Voronoi tessellation. This is a good way of visually verifying whether
+# or not a certain data column is spatially correlated.
 
 ax = geoplot.voronoi(
-    injurious_collisions.sample(1000, random_state=42),
-    hue='NUMBER OF PERSONS INJURED', cmap='Reds', scheme='fisher_jenks',
-    clip=boroughs.geometry,
-    linewidth=0)
-geoplot.polyplot(boroughs, ax=ax)
+    collisions.head(1000), projection=geoplot.crs.AlbersEqualArea(),
+    clip=boroughs.simplify(0.001),
+    hue='NUMBER OF PERSONS INJURED', cmap='Reds', k=None,
+    legend=True,
+    edgecolor='white'
+)
+geoplot.polyplot(boroughs, edgecolor='black', zorder=1, ax=ax)
 
 ###############################################################################
-# Again, these are just some of the plots you can make with Geoplot. There are
-# several other possibilities not covered in this brief introduction. For more
+# These are just some of the plots you can make with Geoplot. There are
+# many other possibilities not covered in this brief introduction. For more
 # examples, refer to the
-# `Gallery <https://residentmario.github.io/geoplot/gallery.html>`_ in the
-# Geoplot documentation.
+# `Gallery <https://residentmario.github.io/geoplot/gallery/index.html>`_ in
+# the Geoplot documentation.
